@@ -26,21 +26,17 @@ class KLineEdit;
 
 class QCheckBox;
 
-template <typename T> class QSharedPointer;
-namespace PimCommon
-{
+template<typename T> class QSharedPointer;
+namespace PimCommon {
 class IncidencesForWidget;
 class ContentTypeWidget;
 }
-namespace KIdentityManagement
-{
+namespace KIdentityManagement {
 class IdentityCombo;
 }
 class QVBoxLayout;
-namespace MailCommon
-{
-
-class FolderCollection;
+namespace MailCommon {
+class FolderSettings;
 class MAILCOMMON_EXPORT CollectionGeneralPage : public Akonadi::CollectionPropertiesPage
 {
     Q_OBJECT
@@ -49,8 +45,8 @@ public:
     explicit CollectionGeneralPage(QWidget *parent = nullptr);
     ~CollectionGeneralPage();
 
-    void load(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
-    void save(Akonadi::Collection &collection) Q_DECL_OVERRIDE;
+    void load(const Akonadi::Collection &collection) override;
+    void save(Akonadi::Collection &collection) override;
 
 protected:
     void init(const Akonadi::Collection &);
@@ -66,19 +62,18 @@ private:
     PimCommon::ContentTypeWidget *mContentsComboBox;
     PimCommon::IncidencesForWidget *mIncidencesForComboBox;
     QCheckBox *mSharedSeenFlagsCheckBox;
-    QCheckBox   *mNotifyOnNewMailCheckBox;
-    QCheckBox   *mKeepRepliesInSameFolderCheckBox;
-    QCheckBox   *mHideInSelectionDialogCheckBox;
-    QCheckBox   *mUseDefaultIdentityCheckBox;
-    KLineEdit   *mNameEdit;
+    QCheckBox *mNotifyOnNewMailCheckBox;
+    QCheckBox *mKeepRepliesInSameFolderCheckBox;
+    QCheckBox *mHideInSelectionDialogCheckBox;
+    QCheckBox *mUseDefaultIdentityCheckBox;
+    KLineEdit *mNameEdit;
     KIdentityManagement::IdentityCombo *mIdentityComboBox;
-    QSharedPointer<MailCommon::FolderCollection> mFolderCollection;
+    QSharedPointer<MailCommon::FolderSettings> mFolderCollection;
     bool mIsLocalSystemFolder;
     bool mIsResourceFolder;
 };
 
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionGeneralPageFactory, CollectionGeneralPage)
-
 }
 
 #endif
