@@ -24,9 +24,7 @@
 
 class QFile;
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 class MailFilter;
 
 class MAILCOMMON_EXPORT FilterImporterThunderbird : public FilterImporterAbstract
@@ -38,6 +36,7 @@ public:
     static QString defaultThunderbirdFiltersSettingsPath();
 
     static QString defaultIcedoveFiltersSettingsPath();
+    static QString defaultSeaMonkeyFiltersSettingsPath();
 private:
     void readStream(QTextStream &stream);
     static QString cleanArgument(const QString &line, const QString &removeStr);
@@ -47,8 +46,6 @@ private:
     bool splitConditions(const QString &cond, MailCommon::MailFilter *filter);
     MailFilter *parseLine(QTextStream &stream, QString line, MailCommon::MailFilter *filter);
 };
-
 }
 
 #endif /* FILTERIMPORTERTHUNDERBIRD_H */
-
