@@ -399,7 +399,7 @@ QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, boo
         MailFilter *f = new MailFilter(*itemFilter->filter());   // deep copy
 
         const QString information = f->purify();
-        if (!f->isEmpty()) {
+        if (!f->isEmpty() && information.isEmpty()) {
             // the filter is valid:
             filters.append(f);
         } else {
